<?php

/**
 * My Spoiler - A plugin that provide a custom button on editor toolbar 
 * to hide object inside a spoiler tag. Depends on Toolbar Container plugin for
 * displaying the button.
 * 
 * This plugin inspired by other MyBB Spoiler plugin made by Sephiroth.
 *  
 * License: New BSD License (http://www.rioastamal.net/mybb/LICENSE.txt)
 */


$plugins->add_hook('toolbar_container_collect', 'my_spoiler_collect');

$plugins->add_hook("parse_message", "my_spoiler_parse_message");
$plugins->add_hook('newthread_start', 'my_spoiler_edit_start');
$plugins->add_hook('newreply_start', 'my_spoiler_edit_start');
$plugins->add_hook('editpost_start', 'my_spoiler_edit_start');
$plugins->add_hook('showthread_start', 'my_spoiler_edit_start');

/*
 * Plugin info function
 */
function my_spoiler_info()
{
    return array(
        "name"           => "My Spoiler",
        "description"    => "Hide object inside the spoiler tag.",
        "website"        => "http://www.rioastamal.net/mybb/my-spoiler/",
        "author"         => "Rio Astamal",
        "authorsite"     => "http://www.rioastamal.net/",
        "version"        => "1.0",
        "guid"           => "549acd10143e88d7c44aedff6281f84f",
        "compatibility"  => "14*"
    );
}

function my_spoiler_activate() {
}

function my_spoiler_deactivate() {
}

/*
 * Function to print plugin version, name, and the website
 * @return string
 */
function get_banner_info() {
   $info = my_spoiler_info();
   return '<a href="' . $info['website'] . '">' . $info['name'] . ' v' . $info['version'] . '</a>';
}

/*
 * Function to parse the [spoiler] tag
 * @param string $message
 * @return void
 */
function my_spoiler_parse_message($message) {
   // sanitize the single and double quote so the javascript doesn't fails
   $message = preg_replace("#\[spoiler=(.*?)\]#e", "'[spoiler='.str_replace( array(\"'\", '\"'), array('', ''), '\\1').']'", $message);
   // little info about plugin
   $banner = get_banner_info();
   
   $long_div = "<div class=\"spoiler_wrap\">
         <div class=\"spoiler_header\">
            <button onclick=\"javascript:
                  if(parentNode.parentNode.getElementsByTagName('div')[1].style.display == 'block'){ 
                     parentNode.parentNode.getElementsByTagName('div')[1].style.display = 'none';
                     this.innerHTML='Spoiler for: $1';
                  } else {
                     parentNode.parentNode.getElementsByTagName('div')[1].style.display = 'block';
                     this.innerHTML='Hide Spoiler';
                  }\">Spoiler for: $1</button>
         </div>
         <div class=\"spoiler_body\" style=\"display: none;\">$2</div>
         <div class=\"spoiler_copy\">" . get_banner_info() . "</div>
      </div>";
   $long_div = preg_replace(array("/\s\s+/", "/\n/"), array(" ", ""), $long_div);   // strip whitespace
    
   $simple_div = "<div class=\"spoiler_wrap\">
         <div class=\"spoiler_header\">
            <button onclick=\"javascript:
                  if(parentNode.parentNode.getElementsByTagName('div')[1].style.display == 'block'){ 
                     parentNode.parentNode.getElementsByTagName('div')[1].style.display = 'none';
                     this.innerHTML='Spoiler:';
                  } else {
                     parentNode.parentNode.getElementsByTagName('div')[1].style.display = 'block';
                     this.innerHTML='Hide Spoiler';
                  }\">Spoiler: </button>
         </div>
         <div class=\"spoiler_body\" style=\"display: none;\">$1</div>
         <div class=\"spoiler_copy\">" . get_banner_info() . "</div>
      </div>";
   $simple_div = preg_replace(array("/\s\s+/", "/\n/"), array(" ", ""), $simple_div); // strip whitespace
   
   $pattern = array("#\[spoiler\](.*?)\[\/spoiler\](\r\n?|\n?)#si", "@\[spoiler=(.*?)\](.*?)\[\/spoiler\](\r\n?|\n?)@si");
   $replace = array($simple_div, $long_div);

   $message = preg_replace($pattern, $replace, $message);
}

/*
 * Function to inject some CSS and javascript to the page header
 * so the icon appears on editor toolbar
 * @return void
 */
function my_spoiler_edit_start() {
   global $headerinclude, $theme, $mybb, $footer;
   
   $css = '
      <!-- start My Spoiler -->
      <style type="text/css">
         .spoiler_wrap {
            position:relative;
         }
         .spoiler_header {
             background: #FFF;
             border: 1px solid #CCC;
             padding: 4px;
             margin: 4px 0 0 0;
             color: #000;
         }
         .spoiler_body {
             background: #FFF;
             padding: 4px;
             border: 1px solid #CCC;
             border-top: 0;
             color: #000;
             margin: 0 0 4px 0;
         }
         .spoiler_copy {
            font-size: 10px;
            position: absolute;
            top: 7px; right: 3px;
         }
      </style>
      <!-- end My Spoiler -->
      ';
   $headerinclude .= $css;
}

/*
 * Function to fill the items attribute of the ItemCollector object
 * that declared on toolbar_contanier plugin. This function only executed
 * when Toolbar Container plugin is active.
 *
 * @param ItemCollector &$ic
 * @return void
 */
function my_spoiler_collect(&$ic) {
   $callback = "
      var spoiler_title = '';
      var ask_title = prompt('Enter the spoiler title(You can leave it blank):', '');
      if (ask_title == null) return;
      if (ask_title != '') {
         spoiler_title = '=' + ask_title;
      }
      clickableEditor.performInsert('[spoiler' + spoiler_title + '][/spoiler]', '', true, false);
   ";
   $toolbar = array(
      'id'     => 'my_spoiler_v10', // make sure it's unique, add version number to make sure
      'name'   => 'my_spoiler',
      'image'  => 'sp-logo.png',
      'callback' => $callback,
      'title'  => 'Hide object inside spoiler'
   );
   $ic->collect_item($toolbar);
}

?>
